==> haskell-tamarin-prover-utils-1.4.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-utils.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-utils
version: 1.4.0
id: tamarin-prover-utils-1.4.0-KOIDZwQj1LN9Jsz965IzQs
key: tamarin-prover-utils-1.4.0-KOIDZwQj1LN9Jsz965IzQs
license: LicenseRef-GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Utility library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
category: Theorem Provers
abi: 4fdd1574363055d46df73d4b71c63843
exposed: True
exposed-modules:
    Control.Basics Control.Monad.Bind Control.Monad.Disj
    Control.Monad.Fresh Control.Monad.Trans.FastFresh
    Control.Monad.Trans.PreciseFresh Data.Color Data.DAG.Simple
    Debug.Trace.Ignore Extension.Data.Bounded Extension.Data.ByteString
    Extension.Data.Label Extension.Data.Monoid Extension.Prelude
    Logic.Connectives System.Timing Text.Dot Text.PrettyPrint.Class
    Text.PrettyPrint.Highlight Text.PrettyPrint.Html Text.Unicode
    Utils.Misc
hidden-modules: Control.Monad.Fresh.Class Control.Monad.Trans.Disj
                Control.Monad.Disj.Class
import-dirs: /usr/lib/ghc-8.4.3/site-local/tamarin-prover-utils-1.4.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/tamarin-prover-utils-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tamarin-prover-utils-1.4.0
hs-libraries: HStamarin-prover-utils-1.4.0-KOIDZwQj1LN9Jsz965IzQs
depends:
    SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73 base-4.11.1.0
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37 binary-0.8.5.1
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    containers-0.5.11.0 deepseq-1.4.3.0
    dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6
    fclabels-2.0.3.3-BHaTfJPZDECEU3fkfof1B1 mtl-2.2.2 pretty-1.1.3.6
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur syb-0.7-2jW43lwzJV5e7EQvU8PxV
    time-1.8.0.2 transformers-0.5.5.0
abi-depends: SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73=7fdfeaf1e3416ffd434c90cf824fb303
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6=f0c6d817a8f4177a2d0e3837521bb503
             fclabels-2.0.3.3-BHaTfJPZDECEU3fkfof1B1=5a2c9099dd962914d18daf9666ad6fa2
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-utils/html/tamarin-prover-utils.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-utils-1.4.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-utils.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-utils
version: 1.4.0
id: tamarin-prover-utils-1.4.0-7rkDMGda8RnH4uQUWwyHwp
key: tamarin-prover-utils-1.4.0-7rkDMGda8RnH4uQUWwyHwp
license: LicenseRef-GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Utility library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
category: Theorem Provers
abi: 7850e689c5d023303e999ad4c3e49536
exposed: True
exposed-modules:
    Control.Basics Control.Monad.Bind Control.Monad.Disj
    Control.Monad.Fresh Control.Monad.Trans.FastFresh
    Control.Monad.Trans.PreciseFresh Data.Color Data.DAG.Simple
    Debug.Trace.Ignore Extension.Data.Bounded Extension.Data.ByteString
    Extension.Data.Label Extension.Data.Monoid Extension.Prelude
    Logic.Connectives System.Timing Text.Dot Text.PrettyPrint.Class
    Text.PrettyPrint.Highlight Text.PrettyPrint.Html Text.Unicode
    Utils.Misc
hidden-modules: Control.Monad.Fresh.Class Control.Monad.Trans.Disj
                Control.Monad.Disj.Class
import-dirs: /usr/lib/ghc-8.6.1/site-local/tamarin-prover-utils-1.4.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/tamarin-prover-utils-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/tamarin-prover-utils-1.4.0
hs-libraries: HStamarin-prover-utils-1.4.0-7rkDMGda8RnH4uQUWwyHwp
depends:
    SHA-1.6.4.4-2lrCL5e5YA7sXuPdJWRCJ base-4.12.0.0
    base64-bytestring-1.0.0.1-G3Br32Wzx6yIe8CvhfIHtS binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    containers-0.6.0.1 deepseq-1.4.4.0
    dlist-0.8.0.5-HU8Aimky3DbFEV0DkwGifS
    fclabels-2.0.3.3-BnphqeNcghO5EF7ELGWEgj mtl-2.2.2 pretty-1.1.3.6
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji syb-0.7-KRW1LCxdMiCJrmhxCvzo37
    time-1.8.0.2 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-utils/html/tamarin-prover-utils.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
